.. _template-patterns:

Template Patterns
=================

Praekelt Molo Mobisite Design System
---------------------------------------

The design system will make it easy to build/scaffold custom Molo mobisites from our Python
Django Molo Framework with a consistent look and feel using predefined Molo Core patterns
and features - without reverse engineering our styles. The Design System and Molo Core serve 
as a single source of truth for our Frontend Templates stack, to help us prevent lose in 
translation for different mobisite applications.


Website Glossary
----------------

These are the Molo sites:

- TuneMe

--

- GEM (Girl Effect Mobile)

--

- FreeBasics

--

- Babycenter

--

- IoGT (Internet of Good Things)


Website Components 
------------------


